/*
 * $Id$
 *
 * The MIT License (MIT)
 * Copyright (c) 2015 Threema GmbH
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE
 */

package ch.threema.apitool.messages;

import java.io.UnsupportedEncodingException;

/**
 * A text message that can be sent/received with end-to-end encryption via Threema.
 */
public class TextMessage extends ThreemaMessage {

	public static final int TYPE_CODE = 0x01;

	private final String text;

	public TextMessage(String text) {
		this.text = text;
	}

	public String getText() {
		return text;
	}

	@Override
	public int getTypeCode() {
		return TYPE_CODE;
	}

	@Override
	public String toString() {
		return text;
	}

	@Override
	public byte[] getData() {
		try {
			return text.getBytes("UTF-8");
		} catch (UnsupportedEncodingException e) {
			return null;
		}
	}
}
